@@ -22,15 +22,9 @@ type Agent struct {
 	bcp     *currentBackup
 	pitrjob *currentPitr
 	mx      sync.Mutex
-	intent  uint32
 	log     *log.Logger
 }
 
-const (
-	intentNone uint32 = iota
-	intentBackup
-)
-
 func New(pbm *pbm.PBM) *Agent {
 	return &Agent{
 		pbm: pbm,
@@ -131,7 +125,7 @@ func (a *Agent) Delete(d pbm.DeleteBackupCmd, opid pbm.OPID, ep pbm.Epoch) {
 		Epoch:   &epts,
 	}, pbm.LockOpCollection)
 
-	got, err := a.aquireLock(lock)
+	got, err := a.aquireLock(lock, l, nil)
 	if err != nil {
 		l.Error("acquire lock: %v", err)
 		return
@@ -198,7 +192,7 @@ func (a *Agent) DeletePITR(d pbm.DeletePITRCmd, opid pbm.OPID, ep pbm.Epoch) {
 		Epoch:   &epts,
 	}, pbm.LockOpCollection)
 
-	got, err := a.aquireLock(lock)
+	got, err := a.aquireLock(lock, l, nil)
 	if err != nil {
 		l.Error("acquire lock: %v", err)
 		return
@@ -257,7 +251,7 @@ func (a *Agent) ResyncStorage(opid pbm.OPID, ep pbm.Epoch) {
 		Epoch:   &epts,
 	})
 
-	got, err := a.aquireLock(lock)
+	got, err := a.aquireLock(lock, l, nil)
 	if err != nil {
 		l.Error("acquiring lock: %v", err)
 		return
@@ -291,21 +285,27 @@ func (a *Agent) ResyncStorage(opid pbm.OPID, ep pbm.Epoch) {
 	l.Debug("epoch set to %v", epch)
 }
 
+type lockAquireFn func() (bool, error)
+
 // aquireLock tries to aquire the lock. If there is a stale lock
 // it tries to mark op that held the lock (backup, [pitr]restore) as failed.
-func (a *Agent) aquireLock(l *pbm.Lock) (got bool, err error) {
-	got, err = l.Acquire()
+func (a *Agent) aquireLock(l *pbm.Lock, lg *log.Event, aquire lockAquireFn) (got bool, err error) {
+	if aquire == nil {
+		aquire = l.Acquire
+	}
+
+	got, err = aquire()
 	if err == nil {
 		return got, nil
 	}
 
 	switch err.(type) {
 	case pbm.ErrDuplicateOp, pbm.ErrConcurrentOp:
-		a.log.Debug("", "", l.OPID, *l.Epoch, "get lock: %v", err)
+		lg.Debug("get lock: %v", err)
 		return false, nil
 	case pbm.ErrWasStaleLock:
 		lk := err.(pbm.ErrWasStaleLock).Lock
-		a.log.Debug("", "", l.OPID, *l.Epoch, "stale lock: %v", lk)
+		lg.Debug("stale lock: %v", lk)
 		var fn func(opid string) error
 		switch lk.Type {
 		case pbm.CmdBackup:
@@ -313,13 +313,13 @@ func (a *Agent) aquireLock(l *pbm.Lock) (got bool, err error) {
 		case pbm.CmdRestore, pbm.CmdPITRestore:
 			fn = a.pbm.MarkRestoreStale
 		default:
-			return l.Acquire()
+			return aquire()
 		}
 		merr := fn(lk.OPID)
 		if merr != nil {
-			a.log.Warning("", "", "", *l.Epoch, "failed to mark stale op '%s' as failed: %v", lk.OPID, merr)
+			lg.Warning("failed to mark stale op '%s' as failed: %v", lk.OPID, merr)
 		}
-		return l.Acquire()
+		return aquire()
 	default:
 		return false, err
 	}
@@ -344,14 +344,14 @@ func (a *Agent) HbStatus() {
 
 	for range tk.C {
 		hb.PBMStatus = a.pbmStatus()
-		logHbStatus("PBM connecion", hb.PBMStatus, l)
+		logHbStatus("PBM connection", hb.PBMStatus, l)
 
 		hb.NodeStatus = a.nodeStatus()
-		logHbStatus("node connecion", hb.NodeStatus, l)
+		logHbStatus("node connection", hb.NodeStatus, l)
 
 		cc++
 		hb.StorageStatus = a.storStatus(l, cc == checkStoreIn)
-		logHbStatus("storage connecion", hb.StorageStatus, l)
+		logHbStatus("storage connection", hb.StorageStatus, l)
 		if cc == checkStoreIn {
 			cc = 0
 		}
