@@ -2,6 +2,7 @@ package pbm
 
 import (
 	"context"
+	"encoding/json"
 	"fmt"
 	"io/ioutil"
 	"regexp"
@@ -39,12 +40,18 @@ func NewCtl(ctx context.Context, host string) (*Ctl, error) {
 func (c *Ctl) PITRon() error {
 	out, err := c.RunCmd("pbm", "config", "--set", "pitr.enabled=true")
 	if err != nil {
-		return err
+		return errors.Wrap(err, "config set pitr.enabled=true")
+	}
+
+	_, err = c.RunCmd("pbm", "config", "--set", "pitr.oplogSpanMin=1")
+	if err != nil {
+		return errors.Wrap(err, "config set pitr.oplogSpanMin=1")
 	}
 
 	fmt.Println("done", out)
 	return nil
 }
+
 func (c *Ctl) PITRoff() error {
 	out, err := c.RunCmd("pbm", "config", "--set", "pitr.enabled=false")
 	if err != nil {
@@ -79,6 +86,65 @@ func (c *Ctl) Backup() (string, error) {
 	return name[1], nil
 }
 
+type ListOut struct {
+	Snapshots []SnapshotStat `json:"snapshots"`
+	PITR      struct {
+		On       bool                   `json:"on"`
+		Ranges   []PitrRange            `json:"ranges"`
+		RsRanges map[string][]PitrRange `json:"rsRanges,omitempty"`
+	} `json:"pitr"`
+}
+
+type SnapshotStat struct {
+	Name       string     `json:"name"`
+	Size       int64      `json:"size,omitempty"`
+	Status     pbm.Status `json:"status"`
+	Err        string     `json:"error,omitempty"`
+	StateTS    int64      `json:"completeTS"`
+	PBMVersion string     `json:"pbmVersion"`
+}
+
+type PitrRange struct {
+	Err   string       `json:"error,omitempty"`
+	Range pbm.Timeline `json:"range"`
+}
+
+func (c *Ctl) List() (*ListOut, error) {
+	o, err := c.RunCmd("pbm", "list", "-o", "json")
+	if err != nil {
+		return nil, errors.Wrap(err, "run pbm list -o json")
+	}
+	l := new(ListOut)
+	err = json.Unmarshal(skipCtl(o), l)
+	if err != nil {
+		return nil, errors.Wrap(err, "unmarshal list")
+	}
+
+	return l, nil
+}
+
+func skipCtl(str string) []byte {
+	for i := 0; i < len(str); i++ {
+		if str[i] == '{' {
+			return []byte(str[i:])
+		}
+	}
+	return []byte(str)
+}
+
+func stripCtl(str string) []byte {
+	b := make([]byte, len(str))
+	var bl int
+	for i := 0; i < len(str); i++ {
+		c := str[i]
+		if c >= 32 && c != 127 {
+			b[bl] = c
+			bl++
+		}
+	}
+	return b[:bl]
+}
+
 func (c *Ctl) CheckBackup(bcpName string, waitFor time.Duration) error {
 	tmr := time.NewTimer(waitFor)
 	tkr := time.NewTicker(500 * time.Millisecond)
