@@ -49,6 +49,11 @@ func (b *Backup) Run(ctx context.Context, bcp pbm.BackupCmd, opid pbm.OPID, l *p
 }
 
 func (b *Backup) Init(bcp pbm.BackupCmd, opid pbm.OPID, balancer pbm.BalancerMode) error {
+	ts, err := b.cn.ClusterTime()
+	if err != nil {
+		return errors.Wrap(err, "read cluster time")
+	}
+
 	meta := &pbm.BackupMeta{
 		OPID:           opid.String(),
 		Name:           bcp.Name,
@@ -57,9 +62,11 @@ func (b *Backup) Init(bcp pbm.BackupCmd, opid pbm.OPID, balancer pbm.BalancerMod
 		Status:         pbm.StatusStarting,
 		Replsets:       []pbm.BackupReplset{},
 		LastWriteTS:    primitive.Timestamp{T: 1, I: 1}, // the driver (mongo?) sets TS to the current wall clock if TS was 0, so have to init with 1
+		FirstWriteTS:   primitive.Timestamp{T: 1, I: 1}, // the driver (mongo?) sets TS to the current wall clock if TS was 0, so have to init with 1
 		PBMVersion:     version.DefaultInfo.Version,
 		Nomination:     []pbm.BackupRsNomination{},
 		BalancerStatus: balancer,
+		Hb:             ts,
 	}
 
 	cfg, err := b.cn.GetConfig()
@@ -154,6 +161,10 @@ func (b *Backup) run(ctx context.Context, bcp pbm.BackupCmd, opid pbm.OPID, l *p
 	if inf.IsLeader() {
 		hbstop := make(chan struct{})
 		defer close(hbstop)
+		err := b.cn.BackupHB(bcp.Name)
+		if err != nil {
+			return errors.Wrap(err, "init heartbeat")
+		}
 		go func() {
 			tk := time.NewTicker(time.Second * 5)
 			defer tk.Stop()
@@ -175,7 +186,9 @@ func (b *Backup) run(ctx context.Context, bcp pbm.BackupCmd, opid pbm.OPID, l *p
 			if err != nil {
 				return errors.Wrap(err, "set balancer OFF")
 			}
-			l.Debug("set balancer off")
+			l.Debug("waiting for balancer off")
+			bs := waitForBalancerOff(b.cn, time.Second*30, l)
+			l.Debug("balancer status: %s", bs)
 		}
 	}
 
@@ -210,7 +223,7 @@ func (b *Backup) run(ctx context.Context, bcp pbm.BackupCmd, opid pbm.OPID, l *p
 
 		err = b.setClusterFirstWrite(bcp.Name)
 		if err != nil {
-			return errors.Wrap(err, "set cluster last write ts")
+			return errors.Wrap(err, "set cluster first write ts")
 		}
 	}
 
@@ -339,6 +352,37 @@ func (b *Backup) run(ctx context.Context, bcp pbm.BackupCmd, opid pbm.OPID, l *p
 	return errors.Wrap(err, "waiting for done")
 }
 
+func waitForBalancerOff(cn *pbm.PBM, t time.Duration, l *plog.Event) pbm.BalancerMode {
+	dn := time.NewTimer(t)
+	defer dn.Stop()
+	tk := time.NewTicker(time.Millisecond * 500)
+	defer tk.Stop()
+
+	var bs *pbm.BalancerStatus
+	var err error
+Loop:
+	for {
+		select {
+		case <-tk.C:
+			bs, err = cn.GetBalancerStatus()
+			if err != nil {
+				l.Error("get balancer status: %v", err)
+				continue
+			}
+			if bs.Mode == pbm.BalancerModeOff {
+				return pbm.BalancerModeOff
+			}
+		case <-dn.C:
+			break Loop
+		}
+	}
+	if bs != nil {
+		return pbm.BalancerMode("")
+	}
+
+	return bs.Mode
+}
+
 const maxReplicationLagTimeSec = 21
 
 // NodeSuits checks if node can perform backup
