@@ -64,12 +64,12 @@ func (s *Slicer) GetSpan() time.Duration {
 func (s *Slicer) Catchup() error {
 	s.l.Debug("start_catchup")
 	baseBcp, err := s.pbm.GetLastBackup(nil)
+	if errors.Is(err, pbm.ErrNotFound) {
+		return errors.New("no backup found, a new backup is required to start PITR")
+	}
 	if err != nil {
 		return errors.Wrap(err, "get last backup")
 	}
-	if baseBcp == nil {
-		return errors.New("no backup found, a new backup is required to start PITR")
-	}
 
 	defer func() {
 		s.l.Debug("lastTS set to %v %s", s.lastTS, formatts(s.lastTS))
@@ -131,9 +131,14 @@ func (s *Slicer) Catchup() error {
 		err = s.upload(chnk.EndTS, baseBcp.FirstWriteTS, chnk.Compression)
 		if err != nil {
 			s.l.Warning("create last_chunk<->sanpshot slice: %v", err)
-			return nil
+			// duplicate key means chunk is already created by probably another routine
+			// so we're safe to continue
+			if !mongo.IsDuplicateKeyError(err) {
+				return nil
+			}
+		} else {
+			s.l.Info("created chunk %s - %s", formatts(chnk.EndTS), formatts(baseBcp.FirstWriteTS))
 		}
-		s.l.Info("created chunk %s - %s", formatts(chnk.EndTS), formatts(baseBcp.FirstWriteTS))
 	}
 
 	err = s.copyFromBcp(baseBcp)
@@ -193,7 +198,7 @@ func (e ErrOpMoved) Error() string {
 const LogStartMsg = "start_ok"
 
 // Stream streaming (saving) chunks of the oplog to the given storage
-func (s *Slicer) Stream(ctx context.Context, wakeupSig <-chan struct{}, compression pbm.CompressionType) error {
+func (s *Slicer) Stream(ctx context.Context, backupSig <-chan *pbm.OPID, compression pbm.CompressionType) error {
 	if s.lastTS.T == 0 {
 		return errors.New("no starting point defined")
 	}
@@ -223,8 +228,23 @@ func (s *Slicer) Stream(ctx context.Context, wakeupSig <-chan struct{}, compress
 			s.l.Info("got done signal, stopping")
 			lastSlice = true
 		// on wakeup or tick whatever comes first do the job
-		case <-wakeupSig:
+		case bcp := <-backupSig:
 			s.l.Info("got wake_up signal")
+			if bcp != nil {
+				s.l.Info("wake_up for bcp %s", bcp.String())
+				sliceTo, err = s.backupStartTS(bcp.String())
+				if err != nil {
+					return errors.Wrap(err, "get backup start TS")
+				}
+
+				// it can happen that prevoius slice >= backup's fisrt_write
+				// in that case we have to just back off.
+				if primitive.CompareTimestamp(s.lastTS, sliceTo) >= 0 {
+					s.l.Info("pausing/stopping with last_ts %v", time.Unix(int64(s.lastTS.T), 0).UTC())
+					return nil
+				}
+				lastSlice = true
+			}
 		case <-tk.C:
 		}
 
@@ -245,26 +265,22 @@ func (s *Slicer) Stream(ctx context.Context, wakeupSig <-chan struct{}, compress
 
 		// before any action check if we still got a lock. if no:
 		//
-		// - if there is another lock and it is the backup operation - wait for the backup
-		//   to start, make the last slice up unlit backup StartTS and return;
+		// - if there is another lock for a backup operation and we've got a
+		//   `backupSig`- wait for the backup to start, make the last slice up
+		//   unlit backup StartTS and return;
 		// - if there is no other lock, we have to wait for the snapshot backup - see above
-		//   (snapshot cmd can delete pitr lock but might not yet acquire the own one)
-		// - if there another lock and that is pitr - return, probably the split happened
-		//   and a new worker was elected
-		// - any other case (including no lock) is the undefined behaviour - return
-		//
-		// if there is no lock, we should wait a bit for a backup lock
-		// because this routine is run concurently with the snapshot
-		// we don't mind to wait here and there, since in during normal (usual) flow
-		// no extra waits won't occure
+		//   (snapshot cmd can delete pitr lock but might not yet acquire the own one);
+		// - if there is another lock and it is for pitr - return, probably split happened
+		//   and a new worker was elected;
+		// - any other case (including no lock) is the undefined behaviour - return.
 		//
 		ld, err := s.getOpLock(llock)
 		if err != nil {
 			return errors.Wrap(err, "check lock")
 		}
 
-		// in case there is a lock, even legit (our own, or backup's one) but it is stale
-		// we sould return so the slicer whould get thru the lock aquisition again.
+		// in case there is a lock, even a legit one (our own, or backup's one) but it is stale
+		// we should return so the slicer would get thru the lock acquisition again.
 		ts, err := s.pbm.ClusterTime()
 		if err != nil {
 			return errors.Wrap(err, "read cluster time")
@@ -282,21 +298,13 @@ func (s *Slicer) Stream(ctx context.Context, wakeupSig <-chan struct{}, compress
 			if err != nil {
 				return errors.Wrap(err, "define last write timestamp")
 			}
-		case pbm.CmdBackup:
-			sliceTo, err = s.backupStartTS(ld.OPID)
-			if err != nil {
-				return errors.Wrap(err, "get backup start TS")
-			}
-
-			// it can happen that prevoius slice >= backup's fisrt write
-			// in that case we have to just back off.
-			if primitive.CompareTimestamp(s.lastTS, sliceTo) >= 0 {
-				s.l.Info("pausing/stopping with last_ts %v", time.Unix(int64(s.lastTS.T), 0).UTC())
-				return nil
-			}
-			lastSlice = true
 		case pbm.CmdUndefined:
 			return errors.New("undefinded behaviour operation is running")
+		case pbm.CmdBackup:
+			// continue only if we had `backupSig`
+			if !lastSlice || primitive.CompareTimestamp(s.lastTS, sliceTo) == 0 {
+				return errors.Errorf("another operation is running: %#v", ld)
+			}
 		default:
 			return errors.Errorf("another operation is running: %#v", ld)
 		}
@@ -396,10 +404,10 @@ func (s *Slicer) backupStartTS(opid string) (ts primitive.Timestamp, err error)
 	defer tk.Stop()
 	for j := 0; j < int(pbm.WaitBackupStart.Seconds()); j++ {
 		b, err := s.pbm.GetBackupByOPID(opid)
-		if err != nil {
+		if err != nil && err != pbm.ErrNotFound {
 			return ts, errors.Wrap(err, "get backup meta")
 		}
-		if b.FirstWriteTS.T > 1 {
+		if b != nil && b.FirstWriteTS.T > 1 {
 			return b.FirstWriteTS, nil
 		}
 		<-tk.C
