@@ -9,6 +9,7 @@ package restore
 
 import (
 	"context"
+	"encoding/json"
 	"fmt"
 	"io"
 	"reflect"
@@ -64,7 +65,7 @@ type Oplog struct {
 
 // NewOplog creates an object for an oplog applying
 func NewOplog(dst *pbm.Node, sv *pbm.MongoVersion, preserveUUID bool) (*Oplog, error) {
-	m, err := ns.NewMatcher(excludeFromRestore)
+	m, err := ns.NewMatcher(append(excludeFromRestore, excludeFromOplog...))
 	if err != nil {
 		return nil, errors.Wrap(err, "create matcher for the collections exclude")
 	}
@@ -149,6 +150,11 @@ func (o *Oplog) handleOp(oe db.Oplog) error {
 		return nil
 	}
 
+	if oe.Operation == "c" && len(oe.Object) > 0 &&
+		(oe.Object[0].Key == "startIndexBuild" || oe.Object[0].Key == "abortIndexBuild") {
+		return nil
+	}
+
 	// optimization not to parse namespace if it remains the same
 	if o.cnamespase != oe.Namespace {
 		o.preserveUUID = o.preserveUUIDopt
@@ -231,6 +237,12 @@ Loop:
 }
 
 func (o *Oplog) handleNonTxnOp(op db.Oplog) error {
+	// have to handle it here one more time because before the op gets thru
+	// txnBuffer its namespace is `collection.$cmd` instead of the real one
+	if o.m.Has(op.Namespace) {
+		return nil
+	}
+
 	op, err := o.filterUUIDs(op)
 	if err != nil {
 		return errors.Wrap(err, "filtering UUIDs from oplog")
@@ -370,7 +382,13 @@ func (o *Oplog) handleNonTxnOp(op db.Oplog) error {
 		}
 	}
 
-	return o.applyOps([]interface{}{op})
+	err = o.applyOps([]interface{}{op})
+	if err != nil {
+		opb, errm := json.Marshal(op)
+		return errors.Wrapf(err, "op: %s | merr %v", opb, errm)
+	}
+
+	return nil
 }
 
 // extractIndexDocumentFromCommitIndexBuilds extracts the index specs out of  "createIndexes" oplog entry and convert to IndexDocument
