@@ -58,6 +58,10 @@ var excludeFromRestore = []string{
 	"config.system.indexBuilds",
 }
 
+var excludeFromOplog = []string{
+	"config.rangeDeletions",
+}
+
 type Restore struct {
 	name     string
 	cn       *pbm.PBM
@@ -179,17 +183,24 @@ func (r *Restore) init(name string, opid pbm.OPID, l *log.Event) (err error) {
 
 	r.opid = opid.String()
 	if r.nodeInfo.IsLeader() {
+		ts, err := r.cn.ClusterTime()
+		if err != nil {
+			return errors.Wrap(err, "init restore meta, read cluster time")
+		}
+
 		meta := &pbm.RestoreMeta{
 			OPID:     r.opid,
 			Name:     r.name,
 			StartTS:  time.Now().Unix(),
 			Status:   pbm.StatusStarting,
 			Replsets: []pbm.RestoreReplset{},
+			Hb:       ts,
 		}
 		err = r.cn.SetRestoreMeta(meta)
 		if err != nil {
 			return errors.Wrap(err, "write backup meta to db")
 		}
+
 		r.stopHB = make(chan struct{})
 		go func() {
 			tk := time.NewTicker(time.Second * 5)
@@ -274,12 +285,12 @@ func (r *Restore) setBcp(bcp string, targetTS primitive.Timestamp) (err error) {
 	}
 
 	r.bcp, err = r.cn.GetLastBackup(&targetTS)
+	if errors.Is(err, pbm.ErrNotFound) {
+		return errors.Errorf("no backup found before ts %v", targetTS)
+	}
 	if err != nil {
 		return errors.Wrap(err, "define last backup")
 	}
-	if r.bcp == nil {
-		return errors.Errorf("no backup found before ts %v", targetTS)
-	}
 
 	return nil
 }
@@ -817,12 +828,16 @@ func (r *Restore) converged(shards []pbm.Shard, status pbm.Status) (bool, error)
 }
 
 func (r *Restore) waitForStatus(status pbm.Status) error {
+	r.log.Debug("waiting for '%s' status", status)
 	tk := time.NewTicker(time.Second * 1)
 	defer tk.Stop()
 	for {
 		select {
 		case <-tk.C:
 			meta, err := r.cn.GetRestoreMeta(r.name)
+			if errors.Is(err, pbm.ErrNotFound) {
+				continue
+			}
 			if err != nil {
 				return errors.Wrap(err, "get restore metadata")
 			}
